@@ -41,20 +41,20 @@ dict_to_options(PyObject *dict)
 */
 static int
 parse_args(PyObject *args, PyObject *kwargs, 
-	   ao_sample_format * format, PyObject **py_options,
+	   ao_sample_format *format, PyObject **py_options,
 	   const char **filename, 
 	   uint_32 *driver_id,
 	   uint_32 *overwrite)
 {
-  static char *driver_id_kwlist[] = {"driver_id", "bits", "rate", 
-				     "channels", "byte_format",
-				     "options", "filename", 
-				     "overwrite", NULL};
-  static char *driver_name_kwlist[] = {"driver_name", "bits", "rate", 
-				       "channels", "byte_format",
-				       "options", "filename", 
-				       "overwrite", NULL};
-
+  static const char *driver_id_kwlist[] = {"driver_id", "bits", "rate", 
+					   "channels", "byte_format",
+					   "options", "filename", 
+					   "overwrite", NULL};
+  static const char *driver_name_kwlist[] = {"driver_name", "bits", 
+					     "rate", 
+					     "channels", "byte_format",
+					     "options", "filename", 
+					     "overwrite", NULL};
   const char *driver_name = NULL;
 
   assert(py_options != NULL);
@@ -69,10 +69,10 @@ parse_args(PyObject *args, PyObject *kwargs,
   format->channels = 2;
   format->byte_format = 1; /* What should this be by default? Anyone? */
   
-  overwrite = 0;
+  *overwrite = 0;
 
   if(PyArg_ParseTupleAndKeywords(args, kwargs, "s|llllO!sl", 
-				 driver_name_kwlist,
+				 (char **) driver_name_kwlist,
 				 &driver_name, 
 				 &format->bits, 
 				 &format->rate, 
@@ -85,7 +85,7 @@ parse_args(PyObject *args, PyObject *kwargs,
   } else {
     PyErr_Clear();
     if(!(PyArg_ParseTupleAndKeywords(args, kwargs, "i|llllO!sl",
-				     driver_id_kwlist,
+				     (char **) driver_id_kwlist,
 				     driver_id, 
 				     &format->bits, 
 				     &format->rate, 
@@ -107,7 +107,7 @@ static PyObject*
 py_ao_new(PyObject *self, PyObject *args, PyObject *kwargs)
 {
   uint_32 overwrite, driver_id;
-  const char * filename = NULL;
+  const char *filename = NULL;
   PyObject *py_options = NULL;
   ao_option *c_options = NULL;
   ao_device *dev;
@@ -129,10 +129,6 @@ py_ao_new(PyObject *self, PyObject *args, PyObject *kwargs)
     }
   }
 
-  if (py_options) {
-    Py_DECREF(py_options);
-  }
-
   if (filename == NULL)
     dev = ao_open_live(driver_id, &sample_format, c_options);
   else
@@ -163,10 +159,10 @@ py_ao_driver_id(PyObject *self, PyObject *args)
   int driver_id;
   char *str = NULL;
 
-  if (!PyArg_ParseTuple(args, "|s", &str))
+  if (!PyArg_ParseTuple(args, "s", &str))
     return NULL;
 
-  driver_id = ao_driver_id(str); /* takes NULL for default */
+  driver_id = ao_driver_id(str);
 
   if (driver_id == -1) {
     PyErr_SetString(Py_aoError, "No such driver");
