@@ -2,7 +2,7 @@
 
 import ao
 
-dev = ao.AudioDevice('wav', bits=16)
+dev = ao.AudioDevice('wav', filename='foo.wav', bits=16)
 f = open('test.wav', 'r')
 data = f.read()
 dev.play(data, len(data))
